<?php
/* Скрипт поиска клиента по номеру телефона в базе данных - пример для сервиса VoiceTal.ru */
/* https://voicetal.ru/blog/recognize-clients/ */

/* НАСТРОЙКИ ДОСТУПА К БАЗЕ ДАННЫХ */
$db_hostname = 'localhost';
//имя пользователя бд
$db_username = '';
//пароль
$db_password = '';
//название базы данных
$db_database = '';
//кодировка таблиц
$db_encode = 'utf8';
/* НАСТРОЙКИ ДОСТУПА К БАЗЕ ДАННЫХ */

/* НАСТРОЙКА ТАБЛИЦЫ С ЗАКАЗАМИ ДЛЯ ПОИСКА ПО ТЕЛЕФОНУ */
//название таблицы с заказами
$cms_tablename = 'order';
//название поля в таблице заказов с ID заказа
$cms_field_id = 'order_id';
//название поля в таблице заказов с телефонов заказчика
$cms_field_phone  = 'telephone';
//название поля в таблице заказов с именем заказчика
$cms_field_name = 'firstname';
//поле с датой добавления заказа для сортировки (чтоб искать сначала в самых новых заказах)
$cms_field_date = 'date_added';
/* НАСТРОЙКА ТАБЛИЦЫ С ЗАКАЗАМИ ДЛЯ ПОИСКА ПО ТЕЛЕФОНУ */

//подключаемся в БД и устанавливаем кодировку
$connect = mysqli_connect($db_hostname, $db_username, $db_password, $db_database);
mysqli_query($connect, "SET NAMES $db_encode");

//проверяем соединение
if (mysqli_connect_errno ())
{
    printf ("Не удалось подключиться к БД: %s\n", mysqli_connect_error ());
    exit ();
}

//в $_GET['phone'] передаем номер звонящего из сервиса VoiceTal
//нормализуем его до нужного нам формата
$phone = normalize_phone ($_GET['phone']);

//составляем запрос в таблицу с заказами
//стоит заметить, что это не самый лучший вариант с точки зрения производительности - 
//при самом худшем варианте, когда данных клиента нет в таблице, мы переберем
//все записи в таблице. если у вас номер телефона хранится в нормализованном формате
//(т.е. формат телефона в таблице всегда один - например 79261234567), то можно изменить запрос
//чтобы искать конкретно этот телефон, а не сравнивать все.
//но т.к. мы хотим сделать максимально универсальный скрипт, то нормализуем телефон в скрипте
$query = "SELECT $cms_field_id,$cms_field_phone,$cms_field_name,$cms_field_date
FROM `$cms_tablename` ORDER BY $cms_field_date DESC LIMIT 10000";
$ret = mysqli_query ($connect, $query);
while ($theme = mysqli_fetch_assoc ($ret))
{
	if ($theme[$cms_field_phone])
	{
		//нормализуем телефон до нужного нам формата
		$order_phone = normalize_phone ($theme[$cms_field_phone]);
		//если телефоны совпадают, то мы нашли, что искали
		if ($order_phone == $phone)
		{
			//подготавливаем данные
			$result = array (
				'status' => true,
				'phone' => $phone,
				'firstname' => $theme[$cms_field_name],
				'order_id' => $theme[$cms_field_id],
				'date_added' => $theme[$cms_field_date]
			);
			//возвращаем результат в VoiceTal
			//значение этих переменных можно будет использовать в схеме звонка
			echo json_encode ($result);
			//результат получен - не смысла перебирать остальные строки таблицы
			die ();
		}
	}
}
//если дошли до сюда, значит телефон не найдет в базе
//возвращаем статус в VoiceTal, что скрипт успешно отработал
echo json_encode (array ('status' => true));

//функция для нормализации телефона
//на входе - любой текстовый или числовой формат
//на выходе - формат 79261234567
function normalize_phone ($phone)
{
	if (!$phone)
		return false;
	$phone = ereg_replace ("[^0-9]",'',$phone);
	$phone = substr ($phone, 0, 11);
	if (strlen ($phone) == 10)
		$phone = '7'.$phone;
	if (strlen ($phone) == 11)
	{
		$phone = substr ($phone, 1, 10);
		$phone = '7'.$phone;
	}
	if (strlen ($phone) == 11)
		return $phone;
	else
		return false;
}
?>
